pub struct BarProcessorConfig {
pub amount_bars: NonZero<u16>,
pub freq_range: Range<NonZero<u16>>,
pub interpolation: InterpolationVariant,
pub sensitivity: f32,
pub bar_distribution: BarDistribution,
}Expand description
The config options for crate::BarProcessor.
Fields
amount_bars: NonZero<u16>Set the amount of bars which should be created.
freq_range: Range<NonZero<u16>>Set the frequency range which the bar processor should consider.
interpolation: InterpolationVariantDecide how the bar values should be interpolated.
sensitivity: f32Control how fast the bars should adjust to their new height.
Should be within the range [0, 1].
bar_distribution: BarDistributionSet the bar distribution. In general you needn’t use another value than its default.