SampleProcessor

Struct SampleProcessor 

pub struct SampleProcessor { /* private fields */ }
Prepares the samples of the fetcher for the crate::BarProcessor.

Implementations

Source

impl SampleProcessor

pub fn new(fetcher: Box<dyn Fetcher>) -> Self

Creates a new instance with the given fetcher where the audio samples are fetched from.

Examples found in repository?
examples/simple.rs (line 4)
3fn main() {
4    let mut sample_processor = SampleProcessor::new(DummyFetcher::new(2));
5    sample_processor.process_next_samples();
6
7    let mut bar_processor = BarProcessor::new(&sample_processor, BarProcessorConfig::default());
8    bar_processor.process_bars(&sample_processor);
9}
More examples
Hide additional examples
examples/default_system_fetcher.rs (line 10)
6fn main() {
7    // Choose default settings
8    let descriptor = SystemAudioFetcherDescriptor::default();
9
10    let mut processor = SampleProcessor::new(SystemAudioFetcher::new(&descriptor).unwrap());
11    let mut bar_processor = BarProcessor::new(&processor, BarProcessorConfig::default());
12
13    // simply fetch
14    processor.process_next_samples();
15    bar_processor.process_bars(&processor);
16}
examples/custom_system_fetcher.rs (line 27)
7fn main() {
8    // get a list of all available devices
9    let available_output_devices = shady_audio::util::get_device_names(DeviceType::Output)
10        .expect("Output devices exists for the given host");
11
12    println!("{:#?}", available_output_devices);
13
14    // choose one
15    let device = shady_audio::util::get_device(
16        available_output_devices.first().unwrap(),
17        DeviceType::Output,
18    )
19    .unwrap()
20    .unwrap();
21
22    let descriptor = SystemAudioFetcherDescriptor {
23        device,
24        ..Default::default()
25    };
26
27    let mut sample_processor = SampleProcessor::new(SystemAudioFetcher::new(&descriptor).unwrap());
28    let mut bar_processor = BarProcessor::new(&sample_processor, BarProcessorConfig::default());
29
30    // start creating the bars
31    sample_processor.process_next_samples();
32    bar_processor.process_bars(&sample_processor);
33}
pub fn process_next_samples(&mut self)

Tell the processor to take some samples of the fetcher and prepare them for the crate::BarProcessors.

Examples found in repository?
examples/simple.rs (line 5)
3fn main() {
4    let mut sample_processor = SampleProcessor::new(DummyFetcher::new(2));
5    sample_processor.process_next_samples();
6
7    let mut bar_processor = BarProcessor::new(&sample_processor, BarProcessorConfig::default());
8    bar_processor.process_bars(&sample_processor);
9}
More examples
Hide additional examples
examples/default_system_fetcher.rs (line 14)
6fn main() {
7    // Choose default settings
8    let descriptor = SystemAudioFetcherDescriptor::default();
9
10    let mut processor = SampleProcessor::new(SystemAudioFetcher::new(&descriptor).unwrap());
11    let mut bar_processor = BarProcessor::new(&processor, BarProcessorConfig::default());
12
13    // simply fetch
14    processor.process_next_samples();
15    bar_processor.process_bars(&processor);
16}
examples/custom_system_fetcher.rs (line 31)
7fn main() {
8    // get a list of all available devices
9    let available_output_devices = shady_audio::util::get_device_names(DeviceType::Output)
10        .expect("Output devices exists for the given host");
11
12    println!("{:#?}", available_output_devices);
13
14    // choose one
15    let device = shady_audio::util::get_device(
16        available_output_devices.first().unwrap(),
17        DeviceType::Output,
18    )
19    .unwrap()
20    .unwrap();
21
22    let descriptor = SystemAudioFetcherDescriptor {
23        device,
24        ..Default::default()
25    };
26
27    let mut sample_processor = SampleProcessor::new(SystemAudioFetcher::new(&descriptor).unwrap());
28    let mut bar_processor = BarProcessor::new(&sample_processor, BarProcessorConfig::default());
29
30    // start creating the bars
31    sample_processor.process_next_samples();
32    bar_processor.process_bars(&sample_processor);
33}